##  Antipatterns
This section addresses antipatterns involving ineffective or counterproductive ways of modeling platform in SAP LeanIX.
  * A platform doesn’t provide features; you wouldn’t use a platform as an end user, but a specific application; it serves as a language for C-level to evolve IT.
  * Don’t confuse platform and tech category. The tech category is a logical grouping of technologies of similar functions (e.g., all of your databases), while the platform is a technical grouping of IT components of one type (e.g., all of your Oracle databases for B2C e-commerce) in relation to the strategic initiatives, business capabilities, and objectives.
